@@ -5,6 +5,7 @@
  * LICENSE file in the root directory of this source tree.
  */
 
+#include <folly/io/IOBuf.h>
 #include <quic/codec/QuicPacketBuilder.h>
 #include <algorithm>
 
@@ -94,7 +95,7 @@ PacketNumEncodingResult encodeLongHeaderHelper(
 }
 
 template <typename BufOp = BufAppender>
-folly::Optional<PacketNumEncodingResult> encodeShortHeaderHelper(
+Optional<PacketNumEncodingResult> encodeShortHeaderHelper(
     const ShortHeader& shortHeader,
     BufOp& bufop,
     uint32_t& spaceCounter,
@@ -104,7 +105,7 @@ folly::Optional<PacketNumEncodingResult> encodeShortHeaderHelper(
   if (spaceCounter <
       1U + packetNumberEncoding.length + shortHeader.getConnectionId().size()) {
     spaceCounter = 0;
-    return folly::none;
+    return none;
   }
   uint8_t initialByte =
       ShortHeader::kFixedBitMask | (packetNumberEncoding.length - 1);
@@ -210,6 +211,28 @@ void RegularQuicPacketBuilder::insert(const BufQueue& buf, size_t limit) {
   insert(std::move(streamData));
 }
 
+void RegularQuicPacketBuilder::insert(
+    const ChainedByteRangeHead& buf,
+    size_t limit) {
+  limit = std::min(limit, buf.chainLength());
+  std::unique_ptr<folly::IOBuf> streamData = folly::IOBuf::wrapBuffer(
+      buf.getHead()->getRange().begin(),
+      std::min(limit, buf.getHead()->length()));
+  limit -= std::min(limit, buf.getHead()->length());
+
+  auto* current = buf.getHead()->getNext();
+  while (limit > 0) {
+    size_t amountToChopOff = std::min(limit, current->length());
+    auto tempBuf =
+        folly::IOBuf::wrapBuffer(current->getRange().begin(), amountToChopOff);
+    streamData->appendToChain(std::move(tempBuf));
+    limit -= amountToChopOff;
+    current = current->getNext();
+  }
+
+  insert(std::move(streamData));
+}
+
 void RegularQuicPacketBuilder::appendFrame(QuicWriteFrame frame) {
   packet_.empty = false;
   packet_.frames.push_back(std::move(frame));
@@ -662,6 +685,13 @@ void InplaceQuicPacketBuilder::insert(const BufQueue& buf, size_t limit) {
   bufWriter_.insert(buf.front(), limit);
 }
 
+void InplaceQuicPacketBuilder::insert(
+    const ChainedByteRangeHead& buf,
+    size_t limit) {
+  remainingBytes_ -= limit;
+  bufWriter_.insert(&buf, limit);
+}
+
 void InplaceQuicPacketBuilder::appendFrame(QuicWriteFrame frame) {
   packet_.empty = false;
   packet_.frames.push_back(std::move(frame));
