@@ -296,7 +296,7 @@ TEST_F(QuicReadCodecTest, PacketDecryptFail) {
 
   auto aead = std::make_unique<MockAead>();
   EXPECT_CALL(*aead, _tryDecrypt(_, _, _))
-      .WillOnce(Invoke([](auto&, const auto, auto) { return folly::none; }));
+      .WillOnce(Invoke([](auto&, const auto, auto) { return none; }));
   auto data = folly::IOBuf::copyBuffer("hello");
   auto streamPacket = createStreamPacket(
       connId,
@@ -396,7 +396,7 @@ TEST_F(QuicReadCodecTest, KeyPhaseOnePacket) {
       *data,
       0 /* cipherOverhead */,
       0 /* largestAcked */,
-      folly::none,
+      none,
       true,
       ProtectionType::KeyPhaseOne);
   AckStates ackStates;
@@ -422,8 +422,7 @@ TEST_F(QuicReadCodecTest, BadResetFirstTwoBits) {
       QuicNodeType::Client);
   EXPECT_CALL(*rawAead, _tryDecrypt(_, _, _))
       .Times(AtMost(1))
-      .WillRepeatedly(
-          Invoke([](auto&, const auto&, auto) { return folly::none; }));
+      .WillRepeatedly(Invoke([](auto&, const auto&, auto) { return none; }));
   PacketNum packetNum = 1;
   StreamId streamId = 2;
   auto data = folly::IOBuf::create(30);
@@ -436,7 +435,7 @@ TEST_F(QuicReadCodecTest, BadResetFirstTwoBits) {
       *data,
       0 /* cipherOverhead */,
       0 /* largestAcked */,
-      folly::none,
+      none,
       true,
       ProtectionType::KeyPhaseZero);
   overridePacketWithToken(streamPacket, tok);
@@ -469,8 +468,7 @@ TEST_F(QuicReadCodecTest, RandomizedShortHeaderLeadsToReset) {
       QuicNodeType::Client);
   EXPECT_CALL(*rawAead, _tryDecrypt(_, _, _))
       .Times(AtMost(1))
-      .WillRepeatedly(
-          Invoke([](auto&, const auto&, auto) { return folly::none; }));
+      .WillRepeatedly(Invoke([](auto&, const auto&, auto) { return none; }));
   PacketNum packetNum = 1;
   StreamId streamId = 2;
   auto data = folly::IOBuf::create(30);
@@ -483,7 +481,7 @@ TEST_F(QuicReadCodecTest, RandomizedShortHeaderLeadsToReset) {
       *data,
       0 /* cipherOverhead */,
       0 /* largestAcked */,
-      folly::none,
+      none,
       true,
       ProtectionType::KeyPhaseZero);
   overridePacketWithToken(streamPacket, tok);
@@ -514,7 +512,7 @@ TEST_F(QuicReadCodecTest, StatelessResetTokenMismatch) {
       QuicNodeType::Client);
   EXPECT_CALL(*rawAead, _tryDecrypt(_, _, _))
       .Times(1)
-      .WillOnce(Invoke([](auto&, const auto&, auto) { return folly::none; }));
+      .WillOnce(Invoke([](auto&, const auto&, auto) { return none; }));
   PacketNum packetNum = 1;
   StreamId streamId = 2;
   auto data = folly::IOBuf::create(30);
@@ -527,7 +525,7 @@ TEST_F(QuicReadCodecTest, StatelessResetTokenMismatch) {
       *data,
       0 /* cipherOverhead */,
       0 /* largestAcked */,
-      folly::none,
+      none,
       true,
       ProtectionType::KeyPhaseZero);
   tok[0] ^= tok[0];
@@ -562,7 +560,7 @@ TEST_F(QuicReadCodecTest, NoOneRttCipherNoReset) {
       *data,
       0 /* cipherOverhead */,
       0 /* largestAcked */,
-      folly::none,
+      none,
       true,
       ProtectionType::KeyPhaseZero);
   overridePacketWithToken(streamPacket, tok);
@@ -590,7 +588,7 @@ TEST_F(QuicReadCodecTest, FailToDecryptLongHeaderNoReset) {
 
   EXPECT_CALL(*rawAead, _tryDecrypt(_, _, _))
       .Times(1)
-      .WillOnce(Invoke([](auto&, const auto&, auto) { return folly::none; }));
+      .WillOnce(Invoke([](auto&, const auto&, auto) { return none; }));
   PacketNum packetNum = 1;
   StreamId streamId = 2;
   auto data = folly::IOBuf::create(30);
@@ -625,7 +623,7 @@ TEST_F(QuicReadCodecTest, FailToDecryptNoTokenNoReset) {
 
   EXPECT_CALL(*rawAead, _tryDecrypt(_, _, _))
       .Times(1)
-      .WillOnce(Invoke([](auto&, const auto&, auto) { return folly::none; }));
+      .WillOnce(Invoke([](auto&, const auto&, auto) { return none; }));
   PacketNum packetNum = 1;
   StreamId streamId = 2;
   auto data = folly::IOBuf::create(30);
@@ -638,7 +636,7 @@ TEST_F(QuicReadCodecTest, FailToDecryptNoTokenNoReset) {
       *data,
       0 /* cipherOverhead */,
       0 /* largestAcked */,
-      folly::none,
+      none,
       true,
       ProtectionType::KeyPhaseZero);
   AckStates ackStates;
@@ -862,7 +860,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateIncomingValid) {
       *data,
       0 /* cipherOverhead */,
       0 /* largestAcked */,
-      folly::none,
+      none,
       true,
       ProtectionType::KeyPhaseZero);
   AckStates ackStates;
@@ -889,7 +887,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateIncomingValid) {
         *data,
         0 /* cipherOverhead */,
         0 /* largestAcked */,
-        folly::none,
+        none,
         true,
         ProtectionType::KeyPhaseOne);
     packetQueue = bufToQueue(packetToBuf(streamPacket));
@@ -925,7 +923,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateIncomingValid) {
         *data,
         0 /* cipherOverhead */,
         0 /* largestAcked */,
-        folly::none,
+        none,
         true,
         ProtectionType::KeyPhaseZero);
     packetQueue = bufToQueue(packetToBuf(streamPacket));
@@ -957,7 +955,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateIncomingValid) {
         *data,
         0 /* cipherOverhead */,
         0 /* largestAcked */,
-        folly::none,
+        none,
         true,
         ProtectionType::KeyPhaseOne);
     packetQueue = bufToQueue(packetToBuf(streamPacket));
@@ -989,7 +987,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateIncomingValid) {
         *data,
         0 /* cipherOverhead */,
         0 /* largestAcked */,
-        folly::none,
+        none,
         true,
         ProtectionType::KeyPhaseZero);
     packetQueue = bufToQueue(packetToBuf(streamPacket));
@@ -1049,7 +1047,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateIncomingInvalid) {
       *data,
       0 /* cipherOverhead */,
       0 /* largestAcked */,
-      folly::none,
+      none,
       true,
       ProtectionType::KeyPhaseZero);
   AckStates ackStates;
@@ -1068,7 +1066,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateIncomingInvalid) {
         .Times(1)
         .WillOnce(Invoke([](std::unique_ptr<folly::IOBuf>&, const auto&, auto) {
           // Failed decryption
-          return folly::none;
+          return none;
         }));
     packetNum = 3;
     streamPacket = createStreamPacket(
@@ -1079,7 +1077,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateIncomingInvalid) {
         *data,
         0 /* cipherOverhead */,
         0 /* largestAcked */,
-        folly::none,
+        none,
         true,
         ProtectionType::KeyPhaseOne);
     packetQueue = bufToQueue(packetToBuf(streamPacket));
@@ -1110,7 +1108,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateIncomingInvalid) {
         *data,
         0 /* cipherOverhead */,
         0 /* largestAcked */,
-        folly::none,
+        none,
         true,
         ProtectionType::KeyPhaseOne);
     packetQueue = bufToQueue(packetToBuf(streamPacket));
@@ -1135,7 +1133,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateIncomingInvalid) {
         .Times(1)
         .WillOnce(Invoke([](std::unique_ptr<folly::IOBuf>&, const auto&, auto) {
           // Failed decryption
-          return folly::none;
+          return none;
         }));
     packetNum = 1;
     streamPacket = createStreamPacket(
@@ -1146,7 +1144,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateIncomingInvalid) {
         *data,
         0 /* cipherOverhead */,
         0 /* largestAcked */,
-        folly::none,
+        none,
         true,
         ProtectionType::KeyPhaseOne);
     packetQueue = bufToQueue(packetToBuf(streamPacket));
@@ -1167,7 +1165,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateIncomingInvalid) {
         .Times(1)
         .WillOnce(Invoke([](std::unique_ptr<folly::IOBuf>&, const auto&, auto) {
           // Failed decryption
-          return folly::none;
+          return none;
         }));
     packetNum = 5;
     streamPacket = createStreamPacket(
@@ -1178,7 +1176,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateIncomingInvalid) {
         *data,
         0 /* cipherOverhead */,
         0 /* largestAcked */,
-        folly::none,
+        none,
         true,
         ProtectionType::KeyPhaseZero);
     packetQueue = bufToQueue(packetToBuf(streamPacket));
@@ -1229,7 +1227,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateCipherUnavailable) {
       *data,
       0 /* cipherOverhead */,
       0 /* largestAcked */,
-      folly::none,
+      none,
       true,
       ProtectionType::KeyPhaseZero);
   AckStates ackStates;
@@ -1253,7 +1251,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateCipherUnavailable) {
         *data,
         0 /* cipherOverhead */,
         0 /* largestAcked */,
-        folly::none,
+        none,
         true,
         ProtectionType::KeyPhaseOne);
     packetQueue = bufToQueue(packetToBuf(streamPacket));
@@ -1277,7 +1275,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateCipherUnavailable) {
         *data,
         0 /* cipherOverhead */,
         0 /* largestAcked */,
-        folly::none,
+        none,
         true,
         ProtectionType::KeyPhaseOne);
     packetQueue = bufToQueue(packetToBuf(streamPacket));
@@ -1331,7 +1329,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateInitiate) {
       *data,
       0 /* cipherOverhead */,
       0 /* largestAcked */,
-      folly::none,
+      none,
       true,
       ProtectionType::KeyPhaseZero);
   AckStates ackStates;
@@ -1377,7 +1375,7 @@ TEST_F(QuicReadCodecTest, KeyUpdateInitiate) {
         *data,
         0 /* cipherOverhead */,
         0 /* largestAcked */,
-        folly::none,
+        none,
         true,
         ProtectionType::KeyPhaseOne);
     packetQueue = bufToQueue(packetToBuf(streamPacket));
