@@ -8,9 +8,14 @@
 #include <quic/common/BufAccessor.h>
 
 namespace quic {
+
+SimpleBufAccessor::SimpleBufAccessor(Buf buf)
+    : buf_(std::move(buf)), capacity_(buf_->capacity()) {
+  CHECK(!buf_->isShared() && !buf_->isChained());
+}
+
 SimpleBufAccessor::SimpleBufAccessor(size_t capacity)
-    : buf_(folly::IOBuf::createCombined(capacity)),
-      capacity_(buf_->capacity()) {}
+    : SimpleBufAccessor(folly::IOBuf::createCombined(capacity)) {}
 
 Buf SimpleBufAccessor::obtain() {
   Buf ret;
