@@ -57,13 +57,25 @@ int QuicServerWorker::getUnfinishedHandshakeCount() {
 
 QuicServerWorker::QuicServerWorker(
     std::shared_ptr<QuicServerWorker::WorkerCallback> callback,
+    TransportSettings transportSettings,
     SetEventCallback ec)
     : callback_(std::move(callback)),
       setEventCallback_(ec),
+      transportSettings_(
+          validateTransportSettings(std::move(transportSettings))),
       takeoverPktHandler_(this),
       observerList_(this) {
   pending0RttData_.setPruneHook(
       [&](auto, auto) { QUIC_STATS(statsCallback_, onZeroRttBufferedPruned); });
+
+  if (transportSettings_.dataPathType == DataPathType::ContinuousMemory) {
+    // TODO: maxBatchSize is only a good start value when each transport does
+    // its own socket writing. If we experiment with multiple transports GSO
+    // together, we will need a better value.
+    bufAccessor_ = std::make_unique<SimpleBufAccessor>(
+        kDefaultMaxUDPPayload * transportSettings_.maxBatchSize);
+    VLOG(10) << "GSO write buf accessor created for ContinuousMemory data path";
+  }
 }
 
 folly::EventBase* QuicServerWorker::getEventBase() const {
@@ -238,8 +250,7 @@ bool QuicServerWorker::maybeSendVersionNegotiationPacketOrDrop(
     bool isInitial,
     LongHeaderInvariant& invariant,
     size_t datagramLen) {
-  folly::Optional<std::pair<VersionNegotiationPacket, Buf>>
-      versionNegotiationPacket;
+  Optional<std::pair<VersionNegotiationPacket, Buf>> versionNegotiationPacket;
   if (isInitial && datagramLen < kMinInitialPacketSize) {
     VLOG(3) << "Dropping initial packet due to invalid size";
     QUIC_STATS(
@@ -442,12 +453,12 @@ void QuicServerWorker::handleNetworkData(
             false, /* isInitial */
             false, /* is0Rtt */
             std::move(maybeParsedShortHeader->destinationConnId),
-            folly::none);
+            none);
         return forwardNetworkData(
             client,
             std::move(routingData),
             NetworkData(std::move(udpPacket)),
-            folly::none, /* quicVersion */
+            none, /* quicVersion */
             isForwardedData);
       }
     } else if (
@@ -599,7 +610,7 @@ void QuicServerWorker::forwardNetworkData(
     const folly::SocketAddress& client,
     RoutingData&& routingData,
     NetworkData&& networkData,
-    folly::Optional<QuicVersion> quicVersion,
+    Optional<QuicVersion> quicVersion,
     bool isForwardedData) {
   // if it's not Client initial or ZeroRtt, AND if the connectionId version
   // mismatches: forward if pktForwarding is enabled else dropPacket
@@ -642,7 +653,7 @@ void QuicServerWorker::setPacingTimer(
 QuicServerTransport::Ptr QuicServerWorker::makeTransport(
     QuicVersion quicVersion,
     const folly::SocketAddress& client,
-    const folly::Optional<ConnectionId>& srcConnId,
+    const Optional<ConnectionId>& srcConnId,
     const ConnectionId& dstConnId,
     bool validNewToken) {
   // create 'accepting' transport
@@ -666,11 +677,6 @@ QuicServerTransport::Ptr QuicServerWorker::makeTransport(
     }
     trans->setCongestionControllerFactory(ccFactory_);
     trans->setTransportStatsCallback(statsCallback_.get()); // ok if nullptr
-    if (quicVersion == QuicVersion::MVFST_EXPERIMENTAL3) {
-      // Use twice the default pacing gain to make BBRv2's startup behavior
-      // similar to BBRv1's.
-      transportSettings_.ccaConfig.overrideStartupPacingGain = 2 * 2.89;
-    }
 
     auto transportSettings = transportSettingsOverrideFn_
         ? transportSettingsOverrideFn_(
@@ -759,7 +765,7 @@ void QuicServerWorker::dispatchPacketData(
     const folly::SocketAddress& client,
     RoutingData&& routingData,
     NetworkData&& networkData,
-    folly::Optional<QuicVersion> quicVersion,
+    Optional<QuicVersion> quicVersion,
     bool isForwardedData) noexcept {
   DCHECK(socket_);
   CHECK(transportFactory_);
@@ -997,23 +1003,23 @@ void QuicServerWorker::sendResetPacket(
   QUIC_STATS(statsCallback_, onStatelessReset);
 }
 
-folly::Optional<std::string> QuicServerWorker::maybeGetEncryptedToken(
+Optional<std::string> QuicServerWorker::maybeGetEncryptedToken(
     folly::io::Cursor& cursor) {
   // Move cursor to the byte right after the initial byte
   if (!cursor.canAdvance(1)) {
-    return folly::none;
+    return none;
   }
   auto initialByte = cursor.readBE<uint8_t>();
 
   // We already know this is an initial packet, which uses a long header
   auto parsedLongHeader = parseLongHeader(initialByte, cursor);
   if (!parsedLongHeader || !parsedLongHeader->parsedLongHeader.has_value()) {
-    return folly::none;
+    return none;
   }
 
   auto header = parsedLongHeader->parsedLongHeader.value().header;
   if (!header.hasToken()) {
-    return folly::none;
+    return none;
   }
   return header.getToken();
 }
@@ -1089,8 +1095,7 @@ void QuicServerWorker::sendRetryPacket(
   auto encryptedToken = generator.encryptToken(retryToken);
 
   CHECK(encryptedToken.has_value());
-  std::string encryptedTokenStr =
-      encryptedToken.value()->moveToFbString().toStdString();
+  std::string encryptedTokenStr = encryptedToken.value()->to<std::string>();
 
   // Create the integrity tag
   // For the tag to be correctly validated by the client, the initalByte
@@ -1232,24 +1237,15 @@ void QuicServerWorker::setFizzContext(
     std::shared_ptr<const fizz::server::FizzServerContext> ctx) {
   ctx_ = ctx;
 }
-
-void QuicServerWorker::setTransportSettings(
+TransportSettings QuicServerWorker::validateTransportSettings(
     TransportSettings transportSettings) {
-  transportSettings_ = transportSettings;
-  if (transportSettings_.batchingMode != QuicBatchingMode::BATCHING_MODE_GSO) {
-    if (transportSettings_.dataPathType == DataPathType::ContinuousMemory) {
+  if (transportSettings.batchingMode != QuicBatchingMode::BATCHING_MODE_GSO) {
+    if (transportSettings.dataPathType == DataPathType::ContinuousMemory) {
       LOG(ERROR) << "Unsupported data path type and batching mode combination";
     }
-    transportSettings_.dataPathType = DataPathType::ChainedMemory;
-  }
-  if (transportSettings_.dataPathType == DataPathType::ContinuousMemory) {
-    // TODO: maxBatchSize is only a good start value when each transport does
-    // its own socket writing. If we experiment with multiple transports GSO
-    // together, we will need a better value.
-    bufAccessor_ = std::make_unique<SimpleBufAccessor>(
-        kDefaultMaxUDPPayload * transportSettings_.maxBatchSize);
-    VLOG(10) << "GSO write buf accessor created for ContinuousMemory data path";
+    transportSettings.dataPathType = DataPathType::ChainedMemory;
   }
+  return transportSettings;
 }
 
 void QuicServerWorker::rejectNewConnections(
@@ -1562,17 +1558,20 @@ size_t QuicServerWorker::SourceIdentityHash::operator()(
   // Zero initialization is intentional here.
   std::array<unsigned char, kKeySize> key{};
 
-  struct sockaddr_storage* storage =
-      reinterpret_cast<struct sockaddr_storage*>(key.data());
+  struct sockaddr_storage storage {};
   const auto& sockaddr = sid.first;
-  sockaddr.getAddress(storage);
+  sockaddr.getAddress(&storage);
+  memcpy(key.data(), &storage, sizeof(struct sockaddr_storage));
 
   unsigned char* connid = key.data() + sizeof(struct sockaddr_storage);
   memcpy(connid, sid.second.data(), sid.second.size());
 
-  uint16_t* port = reinterpret_cast<uint16_t*>(
-      key.data() + sizeof(struct sockaddr_storage) + kMaxConnectionIdSize);
-  *port = sid.first.getPort();
+  uint16_t port;
+  port = sid.first.getPort();
+  memcpy(
+      key.data() + sizeof(struct sockaddr_storage) + kMaxConnectionIdSize,
+      &port,
+      sizeof(uint16_t));
 
   return siphash::siphash24(key.data(), key.size(), &hashKey);
 }
