@@ -45,6 +45,9 @@ class QuicServerWorker : public FollyAsyncUDPSocketAlias::ReadCallback,
   static int getUnfinishedHandshakeCount();
 
  private:
+  static TransportSettings validateTransportSettings(
+      TransportSettings transportSettings);
+
   struct MsgHdr : public folly::EventRecvmsgCallback::MsgHdr {
     static auto constexpr kBuffSize = 1024;
 
@@ -152,7 +155,7 @@ class QuicServerWorker : public FollyAsyncUDPSocketAlias::ReadCallback,
 
  public:
   using TransportSettingsOverrideFn =
-      std::function<folly::Optional<quic::TransportSettings>(
+      std::function<Optional<quic::TransportSettings>(
           const quic::TransportSettings&,
           const folly::IPAddress&)>;
 
@@ -166,7 +169,7 @@ class QuicServerWorker : public FollyAsyncUDPSocketAlias::ReadCallback,
         const folly::SocketAddress& client,
         RoutingData&& routingData,
         NetworkData&& networkData,
-        folly::Optional<QuicVersion> quicVersion,
+        Optional<QuicVersion> quicVersion,
         folly::EventBase* workerEvb,
         bool isForwardedData) = 0;
   };
@@ -175,6 +178,7 @@ class QuicServerWorker : public FollyAsyncUDPSocketAlias::ReadCallback,
 
   explicit QuicServerWorker(
       std::shared_ptr<WorkerCallback> callback,
+      TransportSettings transportSettings = TransportSettings(),
       SetEventCallback ec = SetEventCallback::NONE);
 
   ~QuicServerWorker() override;
@@ -316,8 +320,6 @@ class QuicServerWorker : public FollyAsyncUDPSocketAlias::ReadCallback,
   void setFizzContext(
       std::shared_ptr<const fizz::server::FizzServerContext> ctx);
 
-  void setTransportSettings(TransportSettings transportSettings);
-
   /**
    * If true, start to reject any new connection during handshake
    */
@@ -428,7 +430,7 @@ class QuicServerWorker : public FollyAsyncUDPSocketAlias::ReadCallback,
       const folly::SocketAddress& client,
       RoutingData&& routingData,
       NetworkData&& networkData,
-      folly::Optional<QuicVersion> quicVersion,
+      Optional<QuicVersion> quicVersion,
       bool isForwardedData = false) noexcept;
 
   using ConnIdToTransportMap = folly::
@@ -541,8 +543,7 @@ class QuicServerWorker : public FollyAsyncUDPSocketAlias::ReadCallback,
   /**
    * Tries to get the encrypted retry token from a client initial packet
    */
-  folly::Optional<std::string> maybeGetEncryptedToken(
-      folly::io::Cursor& cursor);
+  Optional<std::string> maybeGetEncryptedToken(folly::io::Cursor& cursor);
 
   bool validRetryToken(
       std::string& encryptedToken,
@@ -600,14 +601,14 @@ class QuicServerWorker : public FollyAsyncUDPSocketAlias::ReadCallback,
       const folly::SocketAddress& client,
       RoutingData&& routingData,
       NetworkData&& networkData,
-      folly::Optional<QuicVersion> quicVersion,
+      Optional<QuicVersion> quicVersion,
       bool isForwardedData = false);
 
   // Create transport and invoke appropriate setters
   QuicServerTransport::Ptr makeTransport(
       QuicVersion quicVersion,
       const folly::SocketAddress& client,
-      const folly::Optional<ConnectionId>& srcConnId,
+      const Optional<ConnectionId>& srcConnId,
       const ConnectionId& dstConnId,
       bool validNewToken);
 
@@ -649,11 +650,11 @@ class QuicServerWorker : public FollyAsyncUDPSocketAlias::ReadCallback,
   bool shutdown_{false};
   std::vector<QuicVersion> supportedVersions_;
   std::shared_ptr<const fizz::server::FizzServerContext> ctx_;
-  TransportSettings transportSettings_;
+  const TransportSettings transportSettings_;
   // Same value as transportSettings_.numGROBuffers_ if the kernel
   // supports GRO. otherwise 1
   uint32_t numGROBuffers_{kDefaultNumGROBuffers};
-  folly::Optional<Buf> healthCheckToken_;
+  Optional<Buf> healthCheckToken_;
   std::function<bool()> rejectNewConnections_{[]() { return false; }};
   std::function<bool(uint16_t)> isBlockListedSrcPort_{
       [](uint16_t) { return false; }};
@@ -681,7 +682,7 @@ class QuicServerWorker : public FollyAsyncUDPSocketAlias::ReadCallback,
   // Rate limits the creation of new connections for this worker.
   std::unique_ptr<RateLimiter> newConnRateLimiter_;
 
-  folly::Optional<std::function<int()>> unfinishedHandshakeLimitFn_;
+  Optional<std::function<int()>> unfinishedHandshakeLimitFn_;
 
   // EventRecvmsgCallback data
   std::unique_ptr<MsgHdr> msgHdr_;
